asr.database.app
================

.. automodule:: asr.database.app

   
   
   .. rubric:: Functions

   
   .. autofunction:: create_key_descriptions
   .. autofunction:: handle_query
   .. autofunction:: initialize_project
   .. autofunction:: row_to_dict
   .. autofunction:: setup_app
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: Summary
   
   

   
   
   